==> payara-embedded-all-5.2022.5-sources.jar: org/glassfish/weld/WeldTerminationListenerProxy.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright [2016] [Payara Foundation and/or its affiliates]
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License.  You can
 * obtain a copy of the License at
 * https://glassfish.dev.java.net/public/CDDL+GPL_1_1.html
 * or packager/legal/LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at packager/legal/LICENSE.txt.
 *
 * GPL Classpath Exception:
 * Oracle designates this particular file as subject to the "Classpath"
 * exception as provided by Oracle in the GPL Version 2 section of the License
 * file that accompanied this code.
 *
 * Modifications:
 * If applicable, add the following below the License Header, with the fields
 * enclosed by brackets [] replaced by your own identifying information:
 * "Portions Copyright [year] [name of copyright owner]"
 *
 * Contributor(s):
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */
package org.glassfish.weld;

import com.sun.enterprise.container.common.spi.util.InjectionException;
import com.sun.enterprise.container.common.spi.util.InjectionManager;
import javax.annotation.PostConstruct;
import javax.enterprise.inject.spi.BeanManager;
import javax.inject.Inject;
import javax.servlet.http.HttpSessionEvent;
import javax.servlet.http.HttpSessionListener;
import org.glassfish.internal.api.Globals;
import org.glassfish.weld.util.Util;

/**
 * checks whether bean manager exists before calling the real listener
 * 
 * @author lprimak
 */
public class WeldTerminationListenerProxy implements HttpSessionListener {
    @PostConstruct
    private void init() {
        try {
            origTermListener = Globals.getDefaultHabitat().getService(InjectionManager.class)
                    .createManagedObject(Util.<HttpSessionListener>classForName(WeldDeployer.WELD_TERMINATION_LISTENER));
        } catch (InjectionException ex) {
            throw new RuntimeException(ex);
        }
    }

    @Override
    public void sessionCreated(HttpSessionEvent se) {
        if(bm != null) {
            origTermListener.sessionCreated(se);
        }
    }

    @Override
    public void sessionDestroyed(HttpSessionEvent se) {
        if(bm != null) {
            origTermListener.sessionDestroyed(se);
        }
    }
    
    
    @Inject
    private BeanManager bm;
    private HttpSessionListener origTermListener;
}

==> payara-embedded-all-6.2023.6-sources.jar: org/glassfish/weld/WeldTerminationListenerProxy.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright [2016] [Payara Foundation and/or its affiliates]
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License.  You can
 * obtain a copy of the License at
 * https://glassfish.dev.java.net/public/CDDL+GPL_1_1.html
 * or packager/legal/LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at packager/legal/LICENSE.txt.
 *
 * GPL Classpath Exception:
 * Oracle designates this particular file as subject to the "Classpath"
 * exception as provided by Oracle in the GPL Version 2 section of the License
 * file that accompanied this code.
 *
 * Modifications:
 * If applicable, add the following below the License Header, with the fields
 * enclosed by brackets [] replaced by your own identifying information:
 * "Portions Copyright [year] [name of copyright owner]"
 *
 * Contributor(s):
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */
package org.glassfish.weld;

import com.sun.enterprise.container.common.spi.util.InjectionException;
import com.sun.enterprise.container.common.spi.util.InjectionManager;
import jakarta.annotation.PostConstruct;
import jakarta.enterprise.inject.spi.BeanManager;
import jakarta.inject.Inject;
import jakarta.servlet.http.HttpSessionEvent;
import jakarta.servlet.http.HttpSessionListener;
import org.glassfish.internal.api.Globals;
import org.glassfish.weld.util.Util;

/**
 * checks whether bean manager exists before calling the real listener
 * 
 * @author lprimak
 */
public class WeldTerminationListenerProxy implements HttpSessionListener {
    @PostConstruct
    private void init() {
        try {
            origTermListener = Globals.getDefaultHabitat().getService(InjectionManager.class)
                    .createManagedObject(Util.<HttpSessionListener>classForName(WeldDeployer.WELD_TERMINATION_LISTENER));
        } catch (InjectionException ex) {
            throw new RuntimeException(ex);
        }
    }

    @Override
    public void sessionCreated(HttpSessionEvent se) {
        if(bm != null) {
            origTermListener.sessionCreated(se);
        }
    }

    @Override
    public void sessionDestroyed(HttpSessionEvent se) {
        if(bm != null) {
            origTermListener.sessionDestroyed(se);
        }
    }
    
    
    @Inject
    private BeanManager bm;
    private HttpSessionListener origTermListener;
}
